From 45e74d5dfa4c5f372df0d3545bc342b6a2505e71 Mon Sep 17 00:00:00 2001
From: Iain Sandoe <iain@sandoe.co.uk>
Date: Sat, 29 Jun 2024 03:10:59 +0100
Subject: [PATCH] jit: Fix Darwin bootstrap after r15-1699.

r15-1699-g445c62ee492 contains changes that trigger two maybe-uninitialized
warnings on Darwin, which result in a bootstrap failure.

Note that the warnings are false positives, in fact the variables should be
initialized in the cases of a switch (all values of the switch condition are
covered).

Fixed here by providing default initializations for the relevant variables.

gcc/jit/ChangeLog:

	* jit-recording.cc
	(recording::memento_of_typeinfo::make_debug_string): Default the value
	of ident.
	(recording::memento_of_typeinfo::write_reproducer): Default the value
	of type.

Signed-off-by: Iain Sandoe <iains@gcc.gnu.org>
---
 gcc/jit/jit-recording.cc | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gcc/jit/jit-recording.cc b/gcc/jit/jit-recording.cc
index f68d01fff55..43a6795f8f3 100644
--- a/gcc/jit/jit-recording.cc
+++ b/gcc/jit/jit-recording.cc
@@ -5516,7 +5516,7 @@ recording::memento_of_typeinfo::replay_into (replayer *r)
 recording::string *
 recording::memento_of_typeinfo::make_debug_string ()
 {
-  const char* ident;
+  const char* ident = "";
   switch (m_info_type)
   {
     case TYPE_INFO_ALIGN_OF:
@@ -5538,7 +5538,7 @@ recording::memento_of_typeinfo::make_debug_string ()
 void
 recording::memento_of_typeinfo::write_reproducer (reproducer &r)
 {
-  const char* type;
+  const char* type = "";
   switch (m_info_type)
   {
     case TYPE_INFO_ALIGN_OF:
-- 
2.39.2 (Apple Git-143)

